#!/bin/bash

# ************************************************************
# *****                   javaspaces.sh                  *****
# *****                                                  *****
# *****        Start and Stop Jini and JavaSpaces        *****
# *****      V1.0, 04/03 - 04/06/2002 by Stefan Witt     *****
# *****      V1.1, 05/04 by Stefan Witt                  *****
# ************************************************************


# This script is used to start the services needed for JavaSpaces under Linux.
# Please note:
#  - If a local firewall is used, it must not block the web server and the
#    multicast messages sent by Jini.
#  - Java forks a new process for each thread. Because of Linux' process
#    management, which does not support leightweight processes like Solaris
#    and Windows do, the system slows down. 128 MB of RAM are needed at least,
#    and a fast CPU is also better. The JavaSpace clients should run on a
#    different machines, but beware: "localhost" must not be used as the
#    webserver address in this case!
#  - If the host is not connected to network, the JavaSpaces clients dump
#    lots and lots of error messages.
#  - This script is Linux specific.



# directory of JDK (Version 1.2 or greater):
export JAVA_HOME=/net/zeus/facstaff/cdyreson/local/java/jdk1.3.1
#export JAVA_HOME=/usr/lib/jdk1.3


# directory of Jini (Version 1.1 or greater):
export JINI_HOME=/.automount/zeus.eecs.wsu.edu/vol/vol0/users/switt/jini1_2
#export JINI_HOME=/home/stefan/jini1_2


# location of web server for remote objects (RMI):
export HOST=nif-c7.eecs.wsu.edu
#export HOST=localhost
export HTTP_PORT=8081



# ************************************************************

# set working directory
export CURRDIR=`pwd`
cd $JAVA_HOME/bin
export PATH=$JAVA_HOME/bin:$PATH

# start HTTP server
echo -n "starting HTTP server at port $HTTP_PORT... "
rm -f $CURRDIR/log-http
./java -jar $JINI_HOME/lib/tools.jar -port $HTTP_PORT -dir $JINI_HOME/lib -verbose >$CURRDIR/log-http &
PID_HTTP_SERVER=$!
echo "done, pid=$PID_HTTP_SERVER"

# start RMI daemon
echo -n "starting RMI daemon... "
rm -rf $CURRDIR/log-rmid
./rmid -J-Djava.security.policy=$JINI_HOME/policy/policy.all -log $CURRDIR/log-rmid &
PID_RMID=$!
echo "done, pid=$PID_RMID"

# start Jini lookup service
echo -n "starting Jini lookup service... "
rm -rf $CURRDIR/log-lookup
./java -Djava.security.policy=$JINI_HOME/policy/policy.all -jar $JINI_HOME/lib/reggie.jar http://$HOST:$HTTP_PORT/reggie-dl.jar $JINI_HOME/policy/policy.all $CURRDIR/log-lookup public
echo "done"

# start transaction manager
echo -n "starting transaction manager... "
rm -rf $CURRDIR/log-txn
./java -Djava.security.policy=$JINI_HOME/policy/policy.all -jar $JINI_HOME/lib/mahalo.jar http://$HOST:$HTTP_PORT/mahalo-dl.jar $JINI_HOME/policy/policy.all $CURRDIR/log-txn public
echo "done"

# start JavaSpace
echo -n "starting persistent JavaSpace... "
# see doc/example/StartingService.html in Jini directory
rm -rf $CURRDIR/log-js
./java -Djava.security.policy=$JINI_HOME/policy/policy.all -jar $JINI_HOME/lib/outrigger.jar http://$HOST:$HTTP_PORT/outrigger-dl.jar $JINI_HOME/policy/policy.all $CURRDIR/log-js &
PID_JS=$!
echo "done, pid=$PID_JS"

# wait for abort
echo "press CTRL-D to stop"
cat >/dev/null

# shut everything down
echo -n "stopping JavaSpaces... "
kill $PID_JS
echo "done"
echo -n "stopping RMI daemon..."
kill $PID_RMID
echo "done"
echo -n "stopping HTTP server... "
kill $PID_HTTP_SERVER
echo "done"
# terminate Java threads (for reggie and mahalo)
echo "stopping remaining Java threads... "
killall java
echo "done"
# clean up
echo -n "cleaning up... "
rm -rf $CURRDIR/log-js/*
rm -rf $CURRDIR/log-js
rm -f $CURRDIR/log-http
rm -rf $CURRDIR/log-rmid
rm -rf $CURRDIR/log-lookup
rm -rf $CURRDIR/log-txn
echo "done"
