// ************************************************************
// *****             CPTS 562 - Final Project             *****
// *****      JavaSpaces Entry For RC4 Cracking Task      *****
// *****             05/03/2002 by Stefan Witt            *****
// ************************************************************

import net.jini.core.entry.*;



/**
  *  This class describes a JavaSpaces entry for an RC4 cipher breaking task.
  *  The server puts these tasks into the space, and the clients perform
  *  the computation and return the result. The ciphertext is shipped to
  *  the clients in a CipherText object via the space.
  *  @author  Stefan Witt
  *  @version 1.0
  */

public class RC4Task implements Entry {
    public int     key[];          /** key that has to be tried upon the ciphertext */
    public String  plainText;      /** plain text to seek in the decrypted data */
    public Boolean done;           /** true, if this task is completed, false otherwise */
    public Boolean plainTextFound; /** result of the cipher breaking (true if plain text found) */


    // ***** Constructor *****
    /**
      *  This constructs an empty RC4Task object. This is needed by
      *  the space proxy (see ch. 2.6.3 on pp. 48-48 in "JavaSpaces Principles,
      *  Patterns, and Practice" for details).
      */

    public RC4Task() {
    }


    // ***** Constructor *****
    /**
      *  Construct an RC4Task object. The task is to decrypt a seperately shipped
      *  cipher text with the given key and search for the known plain text.
      *  @param key       key to use for decryption
      *  @param plainText known plain text
      */

    public RC4Task(int key[], String plainText) {
	int i;

	this.key = new int[key.length];           // copy key
	for (i = 0; i < key.length; i++) {
	    this.key[i] = key[i];
	}
	this.plainText = plainText;               // copy plain text
	this.done = new Boolean(false);           // task not completed yet
	this.plainTextFound = new Boolean(false); // plain text not found yet
    }
}
